Learn R Programming

MultiObjMatch (version 1.0.0)

descr.stats_general: Generate summary statistics for matches

Description

Generate summary statistics for matches

Usage

descr.stats_general(matches, df, treatCol, b.vars, pair.vars, extra = FALSE)

Value

a named vector of summary statistic

Arguments

matches

One matching result from the main matching function

df

the original data frame used for matching

treatCol

the character of the column name for treatment vector

b.vars

the vector of column names of covariates used for measuring balance

pair.vars

the vector of column names used for measuring pairwise distance

extra

the list of summary statistic; it must be the types that can be taken by cobalt