Generate summary statistics for matches
descr.stats_general(matches, df, treatCol, b.vars, pair.vars, extra = FALSE)a named vector of summary statistic
One matching result from the main matching function
the original data frame used for matching
the character of the column name for treatment vector
the vector of column names of covariates used for measuring balance
the vector of column names used for measuring pairwise distance
the list of summary statistic; it must be the types that can be taken by cobalt